@@ -22,7 +22,7 @@
 
 static CalBackendWCAPClass *parent_class = NULL;
 
-#define d(x)	x
+#define d(x)
 
 G_DEFINE_TYPE (CalBackendWCAPEvents, cal_backend_wcap_events,  CAL_BACKEND_WCAP_TYPE);
 
@@ -857,7 +857,9 @@ cal_backend_wcap_events_create_object (ECalBackendSync *backend, EDataCal *cal,
 	ECalBackendSyncStatus result = GNOME_Evolution_Calendar_Success;
 	CalObjModType mod = CALOBJ_MOD_ALL;
 
-	d(printf("cal_backend_wcap_events_create_object(%p, %s, %s)\n", backend, *calobj, *uid));
+	g_return_val_if_fail (calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
+
+	d(printf("cal_backend_wcap_events_create_object(%p, %s)\n", backend, *calobj));
 
 	result = cal_backend_wcap_events_update_objects (backend, cal, *calobj, mod, NULL);
 	*calobj = NULL;
@@ -871,7 +873,9 @@ cal_backend_wcap_events_modify_object (ECalBackendSync *backend, EDataCal *cal,
 {
 	ECalBackendSyncStatus result = GNOME_Evolution_Calendar_Success;
 
-	d(printf("cal_backend_wcap_events_modify_object(%p, %s, %s)\n", backend, calobj, *old_object));
+	g_return_val_if_fail (calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
+
+	d(printf("cal_backend_wcap_events_modify_object(%p, %s)\n", backend, calobj));
 
 	result = cal_backend_wcap_events_update_objects (backend, cal, calobj, mod, old_object);
 
@@ -890,7 +894,7 @@ cal_backend_wcap_events_remove_object (ECalBackendSync *backend, EDataCal *cal,
 	guint error_code;
 	char *calobj;
 	
-	d(printf("cal_backend_wcap_evnets_remove_object(%p, %s, %s, %s)\n", backend, uid, rid, *object));
+	d(printf("cal_backend_wcap_evnets_remove_object(%p, %s, %s)\n", backend, uid, rid));
 
 	if (!cal_backend_wcap_is_online (wcap))
 		return GNOME_Evolution_Calendar_RepositoryOffline;
@@ -991,6 +995,7 @@ cal_backend_wcap_events_get_freebusy (ECalBackendSync *backend, EDataCal *cal, G
 	GList *l;
 	CalBackendWCAP *wcap = CAL_BACKEND_WCAP (backend);
 
+	g_return_val_if_fail (freebusy != NULL, GNOME_Evolution_Calendar_InvalidObject);
 	g_return_val_if_fail (IS_CAL_BACKEND_WCAP (wcap), GNOME_Evolution_Calendar_OtherError);
 
 	d(printf("cal_backend_wcap_get_freebusy(%p)\n", backend));
@@ -1017,6 +1022,8 @@ cal_backend_wcap_events_receive_objects (ECalBackendSync *backend, EDataCal *cal
 	icalcomponent_kind kind;
 	guint error_code;
 
+	g_return_val_if_fail (calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
+
 	d(printf("cal_backend_wcap_receive_objects(%p, %p, %s)\n", backend, cal, calobj));
 
 	g_return_val_if_fail (IS_CAL_BACKEND_WCAP (wcap), GNOME_Evolution_Calendar_OtherError);
