@@ -22,7 +22,7 @@
 
 static CalBackendWCAPClass *parent_class = NULL;
 
-#define d(x)	x
+#define d(x)
 
 G_DEFINE_TYPE (CalBackendWCAPTasks, cal_backend_wcap_tasks,  CAL_BACKEND_WCAP_TYPE);
 
@@ -246,9 +246,9 @@ cal_backend_wcap_tasks_modify_object (ECalBackendSync *backend, EDataCal *cal, c
 {
 	ECalBackendSyncStatus result = GNOME_Evolution_Calendar_Success;
 
-	g_return_val_if_fail (old_object != NULL, GNOME_Evolution_Calendar_InvalidObject);
+	g_return_val_if_fail (calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
 
-	d(printf("cal_backend_wcap_tasks_modify_object(%p, %s, %s)\n", backend, calobj, *old_object));
+	d(printf("cal_backend_wcap_tasks_modify_object(%p, %s)\n", backend, calobj));
 
 	result = cal_backend_wcap_tasks_update_objects (backend, cal, calobj, mod, old_object);
 
@@ -266,9 +266,7 @@ cal_backend_wcap_tasks_remove_object (ECalBackendSync *backend, EDataCal *cal, c
 	guint error_code;
 	char *calobj;
 	
-	g_return_val_if_fail (object != NULL, GNOME_Evolution_Calendar_InvalidObject);
-
-	d(printf("cal_backend_wcap_tasks_remove_object(%p, %s, %s, %s)\n", backend, uid, rid, *object));
+	d(printf("cal_backend_wcap_tasks_remove_object(%p, %s, %s)\n", backend, uid, rid));
 
 	if (!cal_backend_wcap_is_online (wcap))
 		return GNOME_Evolution_Calendar_RepositoryOffline;
@@ -317,6 +315,8 @@ cal_backend_wcap_tasks_receive_objects (ECalBackendSync *backend, EDataCal *cal,
 	icalcomponent_kind kind;
 	guint error_code;
 
+	g_return_val_if_fail (calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
+
 	d(printf("cal_backend_wcap_tasks_receive_objects(%p, %p, %s)\n", backend, cal, calobj));
 
 	g_return_val_if_fail (IS_CAL_BACKEND_WCAP (wcap), GNOME_Evolution_Calendar_OtherError);
