@@ -76,7 +76,7 @@ static void match_object (gpointer key, gpointer value, gpointer data);
 
 static ECalBackendClass *parent_class = NULL;
 
-#define	d(x)	x
+#define	d(x)
 
 G_DEFINE_TYPE (CalBackendWCAP, cal_backend_wcap,  E_TYPE_CAL_BACKEND_SYNC);
 
@@ -1447,14 +1447,13 @@ cal_backend_wcap_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if
 	const char *uristr;
 	int ret;
 	
-	d(printf("cal_backend_wcap_open(%p, %d, %s, %s)\n", backend, only_if_exists, username, password));
+	d(printf("cal_backend_wcap_open(%p, %d)\n", backend, only_if_exists));
 
 	/* check whether already open */
 	if (priv->uri)
 		return GNOME_Evolution_Calendar_Success;
 
 	uristr = e_cal_backend_get_uri (E_CAL_BACKEND (wcap));
-	d(g_message ("uri is %s", uristr));
 
 	g_mutex_lock (priv->open_lock);
 
@@ -1536,7 +1535,6 @@ cal_backend_wcap_remove (ECalBackendSync *backend, EDataCal *cal)
 static ECalBackendSyncStatus
 cal_backend_wcap_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *auid)
 {
-	d(printf("cal_backend_wcap_discard_alarm(%p, %s, %s)\n", backend, uid, auid));
 	return GNOME_Evolution_Calendar_OtherError;
 }
 
@@ -1556,6 +1554,7 @@ cal_backend_wcap_send_objects (ECalBackendSync *backend, EDataCal *cal, const ch
 	CalBackendWCAP *wcap = CAL_BACKEND_WCAP (backend);
 
 	g_return_val_if_fail (users != NULL, GNOME_Evolution_Calendar_InvalidObject);
+	g_return_val_if_fail (calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
 	g_return_val_if_fail (modified_calobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
 
 	d(printf("cal_backend_wcap_send_objects(%p, %s, %s)\n", backend, calobj, *modified_calobj));
@@ -1633,7 +1632,7 @@ cal_backend_wcap_get_object (ECalBackendSync *backend, EDataCal *cal,
 	g_return_val_if_fail (object != NULL, GNOME_Evolution_Calendar_InvalidObject);
 	g_return_val_if_fail (IS_CAL_BACKEND_WCAP (wcap), GNOME_Evolution_Calendar_OtherError);
 
-	d(printf("cal_backend_wcap_get_object(%p, %s, %s)\n", backend, uid, rid));
+	d(printf("cal_backend_wcap_get_object(%p, %s)\n", backend, uid));
 
 	comp = g_hash_table_lookup (priv->objects, uid);
 
@@ -1761,6 +1760,7 @@ cal_backend_wcap_set_default_timezone (ECalBackendSync *backend, EDataCal *cal,
 	CalBackendWCAP *wcap = (CalBackendWCAP *) backend;
 	CalBackendWCAPPrivate *priv = wcap->priv;
 
+	g_return_val_if_fail (tzid != NULL, GNOME_Evolution_Calendar_InvalidObject);
 	g_return_val_if_fail (IS_CAL_BACKEND_WCAP (wcap), GNOME_Evolution_Calendar_OtherError);
 
 	d(printf("cal_backend_wcap_set_default_timezone(%p, %s)\n", backend, tzid));
@@ -1862,6 +1862,7 @@ cal_backend_wcap_get_changes (ECalBackendSync *backend, EDataCal *cal, const cha
 	g_return_val_if_fail (adds != NULL, GNOME_Evolution_Calendar_InvalidObject);
 	g_return_val_if_fail (modifies != NULL, GNOME_Evolution_Calendar_InvalidObject);
 	g_return_val_if_fail (deletes != NULL, GNOME_Evolution_Calendar_InvalidObject);
+	g_return_val_if_fail (change_id != NULL, GNOME_Evolution_Calendar_InvalidObject);
 	d(printf("cal_backend_wcap_get_changes(%p, %s)\n", backend, change_id));
 
 	uristr = e_cal_backend_get_uri (E_CAL_BACKEND (backend));
@@ -1971,7 +1972,7 @@ cal_backend_wcap_start_query (ECalBackend *backend, EDataCalView *view)
 	ECalBackendSyncStatus status;
 	GList *objects = NULL;
 
-	d(printf("cal_backend_wcap_start_query(%p, %s)\n", backend, e_data_cal_view_get_text (view)));
+	d(printf("cal_backend_wcap_start_query(%p)\n", backend));
 
 	status = cal_backend_wcap_get_object_list (E_CAL_BACKEND_SYNC (backend), NULL,
 			e_data_cal_view_get_text (view), &objects);
