@@ -258,16 +258,65 @@ add_folder_tree_item (SunOneFolderTree *tree, SunOneAccount *account, GtkTreeIte
 	g_return_if_fail (model != NULL);
 	priv->invitation_models = g_list_prepend (priv->invitation_models, model);
 
+	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "folder");
+	gtk_tree_store_append (priv->treeview_model, &iter1, iter);
+	gtk_tree_store_set (priv->treeview_model, &iter1,
+				COL_STRING_DISPLAY_NAME, display_name,
+				COL_POINTER_ACCOUNT, account,
+				COL_STRING_FOLDER_TYPE, "folder",
+				COL_STRING_URI, physical_uri,
+				COL_BOOL_IS_STORE, TRUE, 
+				COL_BOOL_IS_ACCOUNT, FALSE,
+				COL_BOOL_IS_PERSONAL, personal,
+				-1);
+	g_free (physical_uri);
+	full_name = g_strdup_printf ("/%s/%s/", sunone_account_get_name (account), calid);
+	full_hash_insert (tree, &iter1, full_name);
+	g_free (full_name);
+
+	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "invitations");
+	gtk_tree_store_append (priv->treeview_model, &iter2, &iter1);
+	gtk_tree_store_set (priv->treeview_model, &iter2,
+				COL_STRING_DISPLAY_NAME, "Invitations",
+				COL_POINTER_ACCOUNT, account,
+				COL_STRING_FOLDER_TYPE, "invitations",
+				COL_STRING_URI, physical_uri,
+				COL_BOOL_IS_STORE, FALSE, 
+				COL_BOOL_IS_ACCOUNT, FALSE,
+				COL_BOOL_IS_PERSONAL, FALSE,
+				-1); 
+	g_free (physical_uri);
+	full_name = g_strdup_printf ("/%s/%s/invitations", sunone_account_get_name (account), calid);
+	full_hash_insert (tree, &iter2, full_name);
+	g_free (full_name);
+#if 0
 	if (personal) {
-		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "invitations");
+		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "folder");
 		gtk_tree_store_append (priv->treeview_model, &iter1, iter);
 		gtk_tree_store_set (priv->treeview_model, &iter1,
+					COL_STRING_DISPLAY_NAME, _("Personal"),
+					COL_POINTER_ACCOUNT, account,
+					COL_STRING_FOLDER_TYPE, "folder",
+					COL_STRING_URI, physical_uri,
+					COL_BOOL_IS_STORE, TRUE, 
+					COL_BOOL_IS_ACCOUNT, FALSE,
+					COL_BOOL_IS_PERSONAL, TRUE,
+					-1);
+		g_free (physical_uri);
+		full_name = g_strdup_printf ("/%s/%s/", sunone_account_get_name (account), calid);
+		full_hash_insert (tree, &iter1, full_name);
+		g_free (full_name);
+
+		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "invitations");
+		gtk_tree_store_append (priv->treeview_model, &iter2, &iter1);
+		gtk_tree_store_set (priv->treeview_model, &iter2,
 					COL_STRING_DISPLAY_NAME, _("Personal Invitations"),
 					COL_POINTER_ACCOUNT, account,
 					COL_STRING_FOLDER_TYPE, "invitations",
 					COL_STRING_URI, physical_uri,
-					COL_BOOL_IS_STORE, 0, 
-					COL_BOOL_IS_ACCOUNT, 0,
+					COL_BOOL_IS_STORE, FALSE, 
+					COL_BOOL_IS_ACCOUNT, FALSE,
+					COL_BOOL_IS_PERSONAL, FALSE,
 					-1);
 		g_free (physical_uri);
 		full_name = g_strdup_printf ("/%s/invitations", sunone_account_get_name (account));
@@ -281,8 +330,9 @@ add_folder_tree_item (SunOneFolderTree *tree, SunOneAccount *account, GtkTreeIte
 					COL_POINTER_ACCOUNT, account,
 					COL_STRING_FOLDER_TYPE, "folder",
 					COL_STRING_URI, physical_uri,
-					COL_BOOL_IS_STORE, 1, 
-					COL_BOOL_IS_ACCOUNT, 0,
+					COL_BOOL_IS_STORE, TRUE, 
+					COL_BOOL_IS_ACCOUNT, FALSE,
+					COL_BOOL_IS_PERSONAL, FALSE,
 					-1);
 		g_free (physical_uri);
 		full_name = g_strdup_printf ("/%s/%s/", sunone_account_get_name (account), calid);
@@ -296,14 +346,16 @@ add_folder_tree_item (SunOneFolderTree *tree, SunOneAccount *account, GtkTreeIte
 					COL_POINTER_ACCOUNT, account,
 					COL_STRING_FOLDER_TYPE, "invitations",
 					COL_STRING_URI, physical_uri,
-					COL_BOOL_IS_STORE, 0, 
-					COL_BOOL_IS_ACCOUNT, 0,
+					COL_BOOL_IS_STORE, FALSE, 
+					COL_BOOL_IS_ACCOUNT, FALSE,
+					COL_BOOL_IS_PERSONAL, FALSE,
 					-1); 
 		g_free (physical_uri);
 		full_name = g_strdup_printf ("/%s/%s/invitations", sunone_account_get_name (account), calid);
 		full_hash_insert (tree, &iter2, full_name);
 		g_free (full_name);
 	}
+#endif
 }
 
 static void
@@ -391,8 +443,9 @@ sunone_folder_tree_created (SunOneFolderTree *tree, SunOneAccount *account)
 				COL_POINTER_ACCOUNT, account,
 				COL_STRING_FOLDER_TYPE, "folder",
 				COL_STRING_URI, physical_uri,
-				COL_BOOL_IS_STORE, 1, 
-				COL_BOOL_IS_ACCOUNT, 1,
+				COL_BOOL_IS_STORE, TRUE, 
+				COL_BOOL_IS_ACCOUNT, TRUE,
+				COL_BOOL_IS_PERSONAL, FALSE,
 				-1);
 	g_free (physical_uri);
 
@@ -477,6 +530,7 @@ sunone_folder_tree_removed (SunOneFolderTree *tree, SunOneAccount *account)
 	g_free (full_name);
 
 	remove_source (account, sunone_account_get_user (account), TRUE);
+	sunone_folder_tree_sync ();
 	sunone_connection_free_preferences (prefs);
 
 	page = sunone_folder_tree_no_view ();
@@ -827,6 +881,7 @@ sft_popup_new_folder_response (GtkWidget *dialog, int response, SunOneFolderTree
 	errcode = sunone_connection_createcalendar (cnc, name, &real_calid);
 	if (SUNONE_ERROR_IS_SUCCESSFUL (errcode)) {
 		sunone_folder_tree_add_calendar (tree, account, real_calid, name);
+		sunone_folder_tree_sync ();
 	} else {
 		error_handler (errcode);
 	}
@@ -1068,6 +1123,7 @@ sft_popup_delete_folder_response (GtkWidget *dialog, int response, SunOneFolderT
 	calid = sunone_util_get_calid_from_uri (physical_uri);
 
 	errcode = sunone_connection_deletecalendar (cnc, calid);
+	sunone_folder_tree_sync ();
 	if (SUNONE_ERROR_IS_SUCCESSFUL (errcode)) {
 		sunone_folder_tree_remove_calendar (tree, account, calid);
 	} else {
@@ -1249,7 +1305,7 @@ sft_tree_popup (SunOneFolderTree *tree, GdkEvent *event)
 	GtkTreeSelection * selection;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	gboolean is_store, is_account;
+	gboolean is_store, is_account, is_personal;
 	guint32 flags = ~0;
 
 	account = sunone_folder_tree_get_account (tree);
@@ -1260,14 +1316,17 @@ sft_tree_popup (SunOneFolderTree *tree, GdkEvent *event)
 	gtk_tree_model_get (model, &iter, COL_POINTER_ACCOUNT, &account,
 				COL_BOOL_IS_STORE, &is_store,
 				COL_BOOL_IS_ACCOUNT, &is_account,
+				COL_BOOL_IS_PERSONAL, &is_personal,
 				-1);
 
 	if (is_account) {
-		flags &= ~(EJ_POPUP_FOLDER_LOGIN | EJ_POPUP_FOLDER_SUB | EJ_POPUP_FOLDER_NEW_CALENDAR | EJ_POPUP_FOLDER_PERM);
+		flags &= ~(EJ_POPUP_FOLDER_LOGIN | EJ_POPUP_FOLDER_SUB | EJ_POPUP_FOLDER_NEW_CALENDAR);
 	} else if (is_store) {
-		flags = ~(EJ_POPUP_FOLDER_OP | EJ_POPUP_FOLDER_PERM);
+		if (is_personal)
+			flags = ~EJ_POPUP_FOLDER_PERM;
+		else
+			flags = ~(EJ_POPUP_FOLDER_OP | EJ_POPUP_FOLDER_PERM);
 	}
-	
 
 	sp = e_popup_new ("org.gnome.evolution-jescs.foldertree.popup");
 	
